@@ -3,17 +3,17 @@ import importlib.util
 import inspect
 import logging
 import os
+import random
 import warnings
 from contextlib import contextmanager
 from socket import gethostname
+from string import ascii_letters
 from typing import Optional, Type, TypeVar
 
 import yaml
 from pydantic import ValidationError
 from pydantic.main import BaseModel
 
-from openmodule_test.utils import DeveloperError
-
 
 def _save_cast(obj, key, to_type, default):
     try:
@@ -84,11 +84,11 @@ def debug():
         return version() == "unknown" and not _inside_docker()
 
 
-def config_file():
-    if testing() or debug():
-        return string("SETTINGS_MODULE", "../src/config.py")
-    else:
-        return string("SETTINGS_MODULE", "config.py")
+def settings_module():
+    if testing() and os.path.exists("../tests/config.py"):
+        return string("SETTINGS_MODULE", "tests.config")
+    return string("SETTINGS_MODULE", "config")
+
 
 
 def log_level() -> int:
@@ -252,8 +252,7 @@ class LazyObject:
             setattr(self._wrapped, name, value)
 
     def __delattr__(self, name):
-        if name == "_wrapped":
-            raise DeveloperError("can't delete _wrapped.")
+        assert name != "_wrapped", "can't delete _wrapped"
         if self._wrapped is empty:
             self._setup()
         delattr(self._wrapped, name)
@@ -301,23 +300,9 @@ class LazySettings(LazyObject):
     def __init__(self):
         super().__init__()
 
-    def _get_module(self, name):
-        module = None
-        path = os.path.abspath(os.path.join(os.getcwd(), name))
-        if os.path.exists(path):
-            spec = importlib.util.spec_from_file_location("config", path)
-            module = importlib.util.module_from_spec(spec)
-            spec.loader.exec_module(module)
-
-        if not module:
-            raise DeveloperError(
-                f"SETTINGS_MODULE at {path} invalid, set it with configure(*) or environment variable SETTINGS_MODULE")
-        return module
-
     def _setup(self):
-        path = config_file()
-        module = self._get_module(path)
-
+        module_name = settings_module()
+        module = importlib.import_module(module_name)
         self._wrapped = Settings(self, module)
 
     def __repr__(self):
@@ -351,8 +336,7 @@ class LazySettings(LazyObject):
         self.__dict__.pop(name, None)
 
     def configure(self, settings_module):
-        if self._wrapped is not empty:
-            raise DeveloperError('Settings are already configured')
+        assert self._wrapped is empty, 'Settings are already configured'
         self._wrapped = Settings(self, settings_module)
 
     def reset(self):
@@ -396,8 +380,7 @@ class OverrideSettings:
                     setattr(self.lazy_setting, k, self.overrides[k][-1])
 
     def set_base(self, lazy_setting, options):
-        if self.lazy_setting is not None:
-            raise DeveloperError("Do not use multiple settings")
+        assert self.lazy_setting is None, "Do not use multiple settings"
         self.lazy_setting = lazy_setting
         overrides = {}
         for k, v in options.items():
@@ -454,3 +437,11 @@ class GlobalSettings:
 
 settings = LazySettings()
 _override_settings = OverrideSettings()
+
+# test settigns for openmodule tests
+NAME = "test"
+RESOURCE = "test-resource"
+VERSION = "test-version"
+random_suffix = "".join(random.choices(ascii_letters, k=10))
+BROKER_SUB = f"inproc://test-sub-{random_suffix}"
+BROKER_PUB = f"inproc://test-pub-{random_suffix}"
