@@ -44,10 +44,11 @@ class Filter:
 
 
 class RPCServer(object):
-    def __init__(self, context, config):
+    def __init__(self, context, config, filter_resource=True):
         self.name = config.NAME
         self.sub = get_sub_socket(context, config)
         self.pub = get_pub_socket(context, config)
+        self.resource = config.RESOURCE if filter_resource else None
         self.handlers: Dict[tuple, HandlerEntry] = {}
         self.filters = []
         self.running = True
@@ -115,6 +116,8 @@ class RPCServer(object):
         return self.thread
 
     def process_rpc(self, channel, message: RPCRequest) -> Optional[Dict]:
+        if self.resource and self.resource != message.resource:
+            return None
         handler: HandlerEntry = self.find_handler(channel, message.type)
         if handler:
             try:
@@ -154,7 +157,6 @@ class RPCServer(object):
         poller.register(self.sub, zmq.POLLIN)
         try:
             while self.running:
-                logging.error("asdf")
                 socks = dict(poller.poll(timeout=1000))
                 if socks.get(self.sub) != zmq.POLLIN:
                     continue
@@ -162,7 +164,6 @@ class RPCServer(object):
                 if topic is None:
                     continue
                 channel = self._channel_from_topic(topic)
-
                 try:
                     message = RPCRequest(**message)
                     message_type = message.type
