@@ -2,6 +2,7 @@ from functools import partial
 from typing import Any
 from unittest import TestCase
 
+from openmodule.config import settings
 from openmodule.dispatcher import MessageDispatcher
 from openmodule.models.base import ZMQMessage
 
@@ -22,6 +23,10 @@ class MessageDispatcherBaseTest(TestCase):
         self.dispatcher = MessageDispatcher()
         self.message = None
 
+    def tearDown(self) -> None:
+        settings.reset()
+        super().tearDown()
+
 
 class MessageDispatcherBasicsTestCase(MessageDispatcherBaseTest):
     def test_topic_is_str(self):
